@@ -4,6 +4,15 @@ var log = function(message) {
     try { window.console.log(message); } catch (e) {};
 }
 
+$.fn.extend({
+    getFaField: function(name) {
+        var id = $(this).attr('id').split('-', 2).join('-');
+        var field = document.getElementById(id+'-'+name);
+        return $(field);
+    }
+});
+
+
 var pluginGen = function(plugin_id, func) {
     return function(name, options) {
         // assume plugin is launch onload
@@ -23,14 +32,45 @@ var pluginGen = function(plugin_id, func) {
 
 $.extend({
   fa_plugins:{},
+  fa_resources:[],
   fa: {
       extend: function(plugins) {
         for (k in plugins) {
             $.extend($.fa_plugins, plugins);
             $.fa[k] = pluginGen(k, plugins[k]);
         }
+      },
+      add_resource: function(url) {
+        if (!url || $.fa_resources.indexOf(url) > -1)
+            return;
+        $.fa_resources.push(url);
+        var head = document.getElementsByTagName("head")[0] || document.documentElement;
+        if (/\.js$/.test(url)) {
+            if ($.browser.safari) {
+                document.write('<scr'+'ipt type="text\/javascr'+'ipt" src="'+url+'"><\/scr'+'ipt>');
+            } else {
+                var obj = document.createElement("script");
+                obj.type= 'text/javascript';
+                obj.src = url;
+                head.insertBefore(obj, head.firstChild);
+            }
+        } else if (/\.css$/.test(url)) {
+            var obj = document.createElement("link");
+            obj.type = 'text/css';
+            obj.rel = 'stylesheet';
+            obj.href = url;
+            head.insertBefore(obj, head.firstChild);
+        } else {
+            log('Invalid resource url: '+url);
+        }
+     }
+  },
+  getFaField: function(name) {
+      field = $('input[id$="'+name+'"]');
+      if (field.length == 1)
+          return field;
   }
-}});
+});
 
 $.fa.extend({
   datepicker: function(field, plugin, options) {
